@@ -86,9 +86,10 @@ extern struct _ValuePairsTransformSet *last_vp_transset;
 extern struct _LogMatcherOptions *last_matcher_options;
 extern struct _HostResolveOptions *last_host_resolve_options;
 extern struct _StatsOptions *last_stats_options;
+extern struct _LogRewrite *last_rewrite;
 
 
-#line 92 "lib/cfg-grammar.h" /* yacc.c:1909  */
+#line 93 "lib/cfg-grammar.h" /* yacc.c:1909  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -114,7 +115,6 @@ extern struct _StatsOptions *last_stats_options;
     LL_CONTEXT_CLIENT_PROTO = 17,
     LL_CONTEXT_SERVER_PROTO = 18,
     LL_CONTEXT_OPTIONS = 19,
-    LL_CONTEXT_HTTP_AUTH_HEADER = 20,
     KW_SOURCE = 10000,
     KW_FILTER = 10001,
     KW_PARSER = 10002,
@@ -179,6 +179,7 @@ extern struct _StatsOptions *last_stats_options;
     KW_PASS_UNIX_CREDENTIALS = 10231,
     KW_PERSIST_NAME = 10302,
     KW_READ_OLD_RECORDS = 10304,
+    KW_USE_SYSLOGNG_PID = 10305,
     KW_FLAGS = 10190,
     KW_PAD_SIZE = 10200,
     KW_TIME_ZONE = 10201,
@@ -202,11 +203,11 @@ extern struct _StatsOptions *last_stats_options;
     KW_TEMPLATE_ESCAPE = 10271,
     KW_TEMPLATE_FUNCTION = 10272,
     KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
+    KW_DEFAULT_SEVERITY = 10301,
     KW_PORT = 10323,
     KW_USE_TIME_RECVD = 10340,
     KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
+    KW_SEVERITY = 10351,
     KW_HOST = 10352,
     KW_MATCH = 10353,
     KW_MESSAGE = 10354,
@@ -214,6 +215,8 @@ extern struct _StatsOptions *last_stats_options;
     KW_TAGS = 10356,
     KW_NETMASK6 = 10357,
     KW_REWRITE = 10370,
+    KW_CONDITION = 10371,
+    KW_VALUE = 10372,
     KW_YES = 10380,
     KW_NO = 10381,
     KW_IFDEF = 10410,
@@ -265,7 +268,6 @@ extern struct _StatsOptions *last_stats_options;
 #define LL_CONTEXT_CLIENT_PROTO 17
 #define LL_CONTEXT_SERVER_PROTO 18
 #define LL_CONTEXT_OPTIONS 19
-#define LL_CONTEXT_HTTP_AUTH_HEADER 20
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
 #define KW_PARSER 10002
@@ -330,6 +332,7 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_PASS_UNIX_CREDENTIALS 10231
 #define KW_PERSIST_NAME 10302
 #define KW_READ_OLD_RECORDS 10304
+#define KW_USE_SYSLOGNG_PID 10305
 #define KW_FLAGS 10190
 #define KW_PAD_SIZE 10200
 #define KW_TIME_ZONE 10201
@@ -353,11 +356,11 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_TEMPLATE_ESCAPE 10271
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
-#define KW_DEFAULT_LEVEL 10301
+#define KW_DEFAULT_SEVERITY 10301
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
-#define KW_LEVEL 10351
+#define KW_SEVERITY 10351
 #define KW_HOST 10352
 #define KW_MATCH 10353
 #define KW_MESSAGE 10354
@@ -365,6 +368,8 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_TAGS 10356
 #define KW_NETMASK6 10357
 #define KW_REWRITE 10370
+#define KW_CONDITION 10371
+#define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
 #define KW_IFDEF 10410
